nm_dict_list=[
  {
    "model": "2x40G",
    "supported: "yes",
    "description": ""
  },
  {
    "model": "4x10G",
    "supported: "yes",
    "description": ""
  },
  {
    "model": "8x10G",
    "supported: "yes",
    "description": ""
  },
  {
    "model": "C3850-NM-2-10G",
    "supported: "no",
    "description": "Catalyst 3850 4 x Gigabit Ethernet/2 x 10 Gigabit Ethernet Network Module"
  },
  {
    "model": "C3850-NM-2-40G",
    "supported: "yes",
    "description": "Catalyst 3850 2 x 40 Gigabit Ethernet Network Module"
  },
  {
    "model": "C3850-NM-4-1G",
    "supported: "yes",
    "description": "Catalyst 3850 4 x Gigabit Ethernet Network Module"
  },
  {
    "model": "C3850-NM-4-10G",
    "supported: "yes",
    "description": "Catalyst 3850 4 x Gigabit Ethernet/4 x 10 Gigabit Ethernet Network Module"
  },
  {
    "model": "C3850-NM-8-10G",
    "supported: "yes",
    "description": "Catalyst 3850 8 x Gigabit Ethernet/8 x 10 Gigabit Ethernet Network Module"
  },
  {
    "model": "C9300-NM-2C",
    "supported: "yes",
    "description": "Catalyst 9300 2 x 100G/40G dual rate QSFP Network Module"
  },
  {
    "model": "C9300-NM-2Q",
    "supported: "yes",
    "description": "Catalyst 9300 2 x 40GE QSFP Network Module"
  },
  {
    "model": "C9300-NM-2Y",
    "supported: "yes",
    "description": "Catalyst 9300 2 x 25G/10G/1G SFP28 Network Module"
  },
  {
    "model": "C9300-NM-4C",
    "supported: "yes",
    "description": "Catalyst 9300 4 x 100G/40G dual rate QSFP Network Module"
  },
  {
    "model": "C9300-NM-4G",
    "supported: "yes",
    "description": "Catalyst 9300 4 x 1GE SFP Network Module"
  },
  {
    "model": "C9300-NM-4M",
    "supported: "yes",
    "description": "Catalyst 9300 4 x 10G/mGig copper Network Module"
  },
  {
    "model": "C9300-NM-8M",
    "supported: "yes",
    "description": "Catalyst 9300X 8 x 10G/mGig copper Network Module"
  },
  {
    "model": "C9300-NM-8X",
    "supported: "yes",
    "description": "Catalyst 9300 8 x 10G/1G SFP+ Network Module"
  },
  {
    "model": "C9300-NM-8Y",
    "supported: "yes",
    "description": "Catalyst 9300 8 x 25G/10G/1G multi-rate SFP Network Module"
  }
]


# Do you want a ton of debug output on the console?
DEBUG = False # ALL DEBUGS
DEBUG_MAIN = False
DEBUG_TRANSLATOR = False
DEBUG_CHECKER = False
DEBUG_REGISTER = False
DEBUG_CLAIM = False
DEBUG_SPLIT = False
DEBUG_FILE = False

# So you want a PDF report generated from the DOCX report (requires MS Word)
PDF = False

# For ngrok to create a web proxy tunnel for the bot
NGROK_AUTHTOKEN = "er9usadfj2349uwdfhusdjadu324hjwwdfjksdfu92348ywdf"

# For netmiko to connect to a switch directly
IOS_USERNAME = 'admin'
IOS_PASSWORD = 'password'
IOS_SECRET = 'secret'
IOS_PORT = 22

# Webex Teams Bot Access Token for this Bot 
TEAMS_TOKEN = "ZTZjMDc5ZTUtN2Q5NS00NzNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNN2_PF84_1eb65fdf-9643-417f-9974-ad72cae0e10f"

# Webex Teams Bot email address for this Bot 
TEAMS_BOT_EMAIL = "mybot@webex.bot"

# Webex Teams Bot email address for this Bot 
TEAMS_BOT_APP_NAME = "My Bot"

# Webex Teams user email who can access our bot
TEAMS_EMAILS = ["somebody@google.com"]

# For meraki SDK to connect to a Dahsboard account
MERAKI_API_KEY = '99NNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNN90'
